InlayHint

Struct InlayHint 

pub struct InlayHint {
    pub position: Position,
    pub label: String,
    pub kind: InlayHintKind,
    pub has_tooltip: bool,
}
An inlay hint from rust-analyzer

Fields

position: Position

Position where the hint should be displayed

label: String

The hint label (type name, parameter name, etc.)

kind: InlayHintKind

Kind of hint

has_tooltip: bool

Whether this hint can be resolved for more details

Implementations

Source

impl InlayHint

pub fn type_hint(position: Position, type_name: impl Into<String>) -> Self

Create a new type hint

pub fn parameter_hint(position: Position, param_name: impl Into<String>) -> Self

Create a new parameter hint

pub fn is_type_hint(&self) -> bool

Check if this is a type hint

pub fn is_parameter_hint(&self) -> bool

Check if this is a parameter hint

pub fn type_name(&self) -> Option<&str>

Get the type name if this is a type hint

pub fn is_copy_type(&self) -> bool

Check if the type is a known Copy type