Module stmt

Module stmt 

Statement-level mutations for PureStmt/PureExpr operations

This module provides mutations that operate at the statement level:

  • ReplaceExprMutation: Replace expressions with other expressions
  • ReplaceExprAtMutation: Replace expression at a specific position using SymbolPath
  • WrapExprMutation: Wrap expressions with macro calls (e.g., dbg!, Some, Ok)
  • RemoveStatementMutation: Remove statements matching a pattern
  • InsertStatementMutation: Insert statements at specific positions
  • ReplaceStatementMutation: Replace statements with other statements

Structs

InsertStatementMutation
Insert a statement at a specific position
RemoveStatementMutation
Remove statements matching a target statement
ReplaceExprAtMutation
Replace an expression at a specific position using index-based navigation
ReplaceExprMutation
Replace an expression with another expression
ReplaceStatementMutation
Replace a statement with another statement
WrapExprMutation
Wrap an expression with a macro call (e.g., dbg!, Some, Ok)

Enums

InsertPosition
Position for inserting statements