pub struct DebugSession { /* private fields */ }Expand description
A session for grouping related debug insertions.
Use this to ensure all debug logs inserted together share the same session ID, making it easy to remove them all at once.
Implementations
Sourceimpl DebugSession
impl DebugSession
Sourcepub fn marker(&self) -> DebugMarker
pub fn marker(&self) -> DebugMarker
Create a marker for this session.
Sourcepub fn marker_with_desc(&self, description: impl Into<String>) -> DebugMarker
pub fn marker_with_desc(&self, description: impl Into<String>) -> DebugMarker
Create a marker with a description for this session.