pub struct AnalyzerClient { /* private fields */ }Expand description
Client for communicating with rust-analyzer
This is a lightweight wrapper that can use an existing LSP connection or spawn a new rust-analyzer instance.
Implementations
Sourceimpl AnalyzerClient
impl AnalyzerClient
Sourcepub fn new(workspace_root: impl AsRef<Path>) -> Self
pub fn new(workspace_root: impl AsRef<Path>) -> Self
Create a new analyzer client for a workspace
Sourcepub fn workspace_root(&self) -> &Path
pub fn workspace_root(&self) -> &Path
Get the workspace root
Sourcepub fn is_likely_copy(&self, type_name: &str) -> bool
pub fn is_likely_copy(&self, type_name: &str) -> bool
Check if a type is Copy based on known patterns
This is a heuristic check. For accurate results, use InlayHints with actual type information from rust-analyzer.