pub struct InlayHint {
pub position: Position,
pub label: String,
pub kind: InlayHintKind,
pub has_tooltip: bool,
}Expand description
An inlay hint from rust-analyzer
Fields
position: PositionPosition where the hint should be displayed
label: StringThe hint label (type name, parameter name, etc.)
kind: InlayHintKindKind of hint
has_tooltip: boolWhether this hint can be resolved for more details
Implementations
Sourceimpl InlayHint
impl InlayHint
Sourcepub fn type_hint(position: Position, type_name: impl Into<String>) -> Self
pub fn type_hint(position: Position, type_name: impl Into<String>) -> Self
Create a new type hint
Sourcepub fn parameter_hint(position: Position, param_name: impl Into<String>) -> Self
pub fn parameter_hint(position: Position, param_name: impl Into<String>) -> Self
Create a new parameter hint
Sourcepub fn is_type_hint(&self) -> bool
pub fn is_type_hint(&self) -> bool
Check if this is a type hint
Sourcepub fn is_parameter_hint(&self) -> bool
pub fn is_parameter_hint(&self) -> bool
Check if this is a parameter hint
Sourcepub fn is_copy_type(&self) -> bool
pub fn is_copy_type(&self) -> bool
Check if the type is a known Copy type