Statement-level mutations for PureStmt/PureExpr operations
This module provides mutations that operate at the statement level:
ReplaceExprMutation: Replace expressions with other expressionsReplaceExprAtMutation: Replace expression at a specific position using SymbolPathWrapExprMutation: Wrap expressions with macro calls (e.g., dbg!, Some, Ok)RemoveStatementMutation: Remove statements matching a patternInsertStatementMutation: Insert statements at specific positionsReplaceStatementMutation: Replace statements with other statements
Structs
- Insert
Statement Mutation - Insert a statement at a specific position
- Remove
Statement Mutation - Remove statements matching a target statement
- Replace
Expr AtMutation - Replace an expression at a specific position using index-based navigation
- Replace
Expr Mutation - Replace an expression with another expression
- Replace
Statement Mutation - Replace a statement with another statement
- Wrap
Expr Mutation - Wrap an expression with a macro call (e.g., dbg!, Some, Ok)
Enums
- Insert
Position - Position for inserting statements