DebugSession

Struct DebugSession 

pub struct DebugSession { /* private fields */ }
A session for grouping related debug insertions.

Use this to ensure all debug logs inserted together share the same session ID, making it easy to remove them all at once.

Implementations

Source

impl DebugSession

pub fn new() -> Self

Create a new debug session.

pub fn with_id(session_id: impl Into<String>) -> Self

Create a session with a specific ID.

pub fn id(&self) -> &str

Get the session ID.

pub fn marker(&self) -> DebugMarker

Create a marker for this session.

pub fn marker_with_desc(&self, description: impl Into<String>) -> DebugMarker

Create a marker with a description for this session.